@@ -7,16 +7,16 @@ predict.ridgeLinear <- function(object, newdata,
     na.action = na.pass, all.coef = FALSE, ...)
   {
     tt <- terms(object)
-    if (!inherits(object, "ridgeLinear")) 
+    
+    if (!inherits(object, "ridgeLinear")) {
       warning("calling predict.ridgeLinear(<fake-ridgeLinear-object>) ...")
-    if (missing(newdata) || is.null(newdata)) {
-      # model.matrix handles factors properly, and includes an intercept term
-      # TODO(dan): Add xlev here?
-      mm <- X <- model.matrix(object, data=model.frame(formula=tt, data=object$model_frame))
-      mmDone <- TRUE
-      offset <- object$offset
     }
-    else {
+    
+    if (missing(newdata) || is.null(newdata)) {
+      newdata <- object$model_frame
+    }
+    
+  
       Terms <- delete.response(tt)
       m <- model.frame(Terms, newdata, na.action = na.action, 
                        xlev = object$xlevels)
@@ -29,9 +29,9 @@ predict.ridgeLinear <- function(object, newdata,
                                                         "variables")[[i + 1]], newdata)
       if (!is.null(object$call$offset)) 
         offset <- offset + eval(object$call$offset, newdata)
-      mmDone <- FALSE
-    }
+    
     beta <- coef(object, all.coef = all.coef)
+    
     if(all.coef)
       res <- apply(beta, 1, function(x){drop(as.matrix(mm) %*% x)})
     else
